@@ -1,5 +1,5 @@
 from django.db import models
-from books.models import Book
+from plicata.books.models import Book
 
 
 class Character(models.Model):
