@@ -7,5 +7,7 @@ class Setting(models.Model):
     tagline = models.CharField(max_length=255, blank=True, null=True)
     setting = RichTextField(blank=True, null=True)
     books = models.ManyToManyField(Book)
+    def __unicode__(self):
+        return self.name
     class Meta:
         db_table = 'plicta_setting_setting'
